"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class VertexAiDatasetXEncryptionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    kms_key_name: builtins.str
    def __init__(
        self,
        *,
        kms_key_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_name", b"kms_key_name"]) -> None: ...

global___VertexAiDatasetXEncryptionSpec = VertexAiDatasetXEncryptionSpec

@typing_extensions.final
class VertexAiDatasetXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___VertexAiDatasetXTimeouts = VertexAiDatasetXTimeouts

@typing_extensions.final
class VertexAiDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    METADATA_SCHEMA_URI_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    ENCRYPTION_SPEC_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    display_name: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    metadata_schema_uri: builtins.str
    name: builtins.str
    project: builtins.str
    region: builtins.str
    update_time: builtins.str
    @property
    def encryption_spec(self) -> global___VertexAiDatasetXEncryptionSpec: ...
    @property
    def timeouts(self) -> global___VertexAiDatasetXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metadata_schema_uri: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        update_time: builtins.str = ...,
        encryption_spec: global___VertexAiDatasetXEncryptionSpec | None = ...,
        timeouts: global___VertexAiDatasetXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption_spec", b"encryption_spec", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "display_name", b"display_name", "encryption_spec", b"encryption_spec", "id", b"id", "labels", b"labels", "metadata_schema_uri", b"metadata_schema_uri", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___VertexAiDataset = VertexAiDataset



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_forwarding.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n gcp/gcp_compute_forwarding.proto\x12\"oak9.tython.gcp.compute_forwarding\x1a\x13shared/shared.proto\"Y\n3ComputeForwardingRuleXServiceDirectoryRegistrations\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\"P\n\x1e\x43omputeForwardingRuleXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcf\x07\n\x15\x43omputeForwardingRule\x12\x11\n\tall_ports\x18\x01 \x01(\x08\x12\x1b\n\x13\x61llow_global_access\x18\x02 \x01(\x08\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x03 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x12\n\nip_address\x18\x07 \x01(\t\x12\x13\n\x0bip_protocol\x18\x08 \x01(\t\x12\x1e\n\x16is_mirroring_collector\x18\t \x01(\x08\x12\x19\n\x11label_fingerprint\x18\n \x01(\t\x12U\n\x06labels\x18\x0b \x03(\x0b\x32\x45.oak9.tython.gcp.compute_forwarding.ComputeForwardingRule.LabelsEntry\x12\x1d\n\x15load_balancing_scheme\x18\x0c \x01(\t\x12\x0c\n\x04name\x18\r \x01(\t\x12\x0f\n\x07network\x18\x0e \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x0f \x01(\t\x12\x12\n\nport_range\x18\x10 \x01(\t\x12\r\n\x05ports\x18\x11 \x03(\t\x12\x0f\n\x07project\x18\x12 \x01(\t\x12\x19\n\x11psc_connection_id\x18\x13 \x01(\t\x12\x1d\n\x15psc_connection_status\x18\x14 \x01(\t\x12\x0e\n\x06region\x18\x15 \x01(\t\x12\x11\n\tself_link\x18\x16 \x01(\t\x12\x15\n\rservice_label\x18\x17 \x01(\t\x12\x14\n\x0cservice_name\x18\x18 \x01(\t\x12\x12\n\nsubnetwork\x18\x19 \x01(\t\x12\x0e\n\x06target\x18\x1a \x01(\t\x12\x80\x01\n\x1fservice_directory_registrations\x18\x1b \x03(\x0b\x32W.oak9.tython.gcp.compute_forwarding.ComputeForwardingRuleXServiceDirectoryRegistrations\x12T\n\x08timeouts\x18\x1c \x01(\x0b\x32\x42.oak9.tython.gcp.compute_forwarding.ComputeForwardingRuleXTimeouts\x12\x37\n\rresource_info\x18\x1d \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_forwarding_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEFORWARDINGRULE_LABELSENTRY._options = None
  _COMPUTEFORWARDINGRULE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEFORWARDINGRULEXSERVICEDIRECTORYREGISTRATIONS._serialized_start=93
  _COMPUTEFORWARDINGRULEXSERVICEDIRECTORYREGISTRATIONS._serialized_end=182
  _COMPUTEFORWARDINGRULEXTIMEOUTS._serialized_start=184
  _COMPUTEFORWARDINGRULEXTIMEOUTS._serialized_end=264
  _COMPUTEFORWARDINGRULE._serialized_start=267
  _COMPUTEFORWARDINGRULE._serialized_end=1242
  _COMPUTEFORWARDINGRULE_LABELSENTRY._serialized_start=1197
  _COMPUTEFORWARDINGRULE_LABELSENTRY._serialized_end=1242
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeInterconnectAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeInterconnectAttachmentXTimeouts = ComputeInterconnectAttachmentXTimeouts

@typing_extensions.final
class ComputeInterconnectAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PrivateInterconnectInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADMIN_ENABLED_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CANDIDATE_SUBNETS_FIELD_NUMBER: builtins.int
    CLOUD_ROUTER_IP_ADDRESS_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CUSTOMER_ROUTER_IP_ADDRESS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EDGE_AVAILABILITY_DOMAIN_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    GOOGLE_REFERENCE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INTERCONNECT_FIELD_NUMBER: builtins.int
    IPSEC_INTERNAL_ADDRESSES_FIELD_NUMBER: builtins.int
    MTU_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PAIRING_KEY_FIELD_NUMBER: builtins.int
    PARTNER_ASN_FIELD_NUMBER: builtins.int
    PRIVATE_INTERCONNECT_INFO_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROUTER_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VLAN_TAG8021Q_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    admin_enabled: builtins.bool
    bandwidth: builtins.str
    @property
    def candidate_subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    cloud_router_ip_address: builtins.str
    creation_timestamp: builtins.str
    customer_router_ip_address: builtins.str
    description: builtins.str
    edge_availability_domain: builtins.str
    encryption: builtins.str
    google_reference_id: builtins.str
    id: builtins.str
    interconnect: builtins.str
    @property
    def ipsec_internal_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    mtu: builtins.str
    name: builtins.str
    pairing_key: builtins.str
    partner_asn: builtins.str
    @property
    def private_interconnect_info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    project: builtins.str
    region: builtins.str
    router: builtins.str
    self_link: builtins.str
    state: builtins.str
    type: builtins.str
    vlan_tag8021q: builtins.float
    @property
    def timeouts(self) -> global___ComputeInterconnectAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        admin_enabled: builtins.bool = ...,
        bandwidth: builtins.str = ...,
        candidate_subnets: collections.abc.Iterable[builtins.str] | None = ...,
        cloud_router_ip_address: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        customer_router_ip_address: builtins.str = ...,
        description: builtins.str = ...,
        edge_availability_domain: builtins.str = ...,
        encryption: builtins.str = ...,
        google_reference_id: builtins.str = ...,
        id: builtins.str = ...,
        interconnect: builtins.str = ...,
        ipsec_internal_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        mtu: builtins.str = ...,
        name: builtins.str = ...,
        pairing_key: builtins.str = ...,
        partner_asn: builtins.str = ...,
        private_interconnect_info: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        router: builtins.str = ...,
        self_link: builtins.str = ...,
        state: builtins.str = ...,
        type: builtins.str = ...,
        vlan_tag8021q: builtins.float = ...,
        timeouts: global___ComputeInterconnectAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_enabled", b"admin_enabled", "bandwidth", b"bandwidth", "candidate_subnets", b"candidate_subnets", "cloud_router_ip_address", b"cloud_router_ip_address", "creation_timestamp", b"creation_timestamp", "customer_router_ip_address", b"customer_router_ip_address", "description", b"description", "edge_availability_domain", b"edge_availability_domain", "encryption", b"encryption", "google_reference_id", b"google_reference_id", "id", b"id", "interconnect", b"interconnect", "ipsec_internal_addresses", b"ipsec_internal_addresses", "mtu", b"mtu", "name", b"name", "pairing_key", b"pairing_key", "partner_asn", b"partner_asn", "private_interconnect_info", b"private_interconnect_info", "project", b"project", "region", b"region", "resource_info", b"resource_info", "router", b"router", "self_link", b"self_link", "state", b"state", "timeouts", b"timeouts", "type", b"type", "vlan_tag8021q", b"vlan_tag8021q"]) -> None: ...

global___ComputeInterconnectAttachment = ComputeInterconnectAttachment



import re
from core.bp_metadata_utils.policy_implementation_docstring import PolicyImplementationDocstring

# implements_pattern = re.compile('^\s+Implements:\s*[\r\n](?P<desc>[\S\s]+)Returns', re.MULTILINE)
# desc_pattern = re.compile('^\s+Desc:\s*[\r\n](?P<desc>[\S\s]+)Implements', re.MULTILINE)

author_pattern = re.compile('(Author:\n\s+((((?P<author>.+(?:\n.*?|\Z)+(\s*)))(Name:|Desc:|\Z))))', re.MULTILINE)
desc_pattern = re.compile('(Desc:\n\s+((((?P<desc>.+(?:\n.*?|\Z)+(\s*)))(Name:|Author:|\Z))))', re.MULTILINE)
no_desc_pattern = re.compile('(((((?P<nodesc>.+(?:\n.*?|\Z)+(\s*)))(Name:|Author:|\Z))))', re.MULTILINE)
name_pattern = re.compile('(Name:\n\s+((?P<name>.+(?:\n.*?|\Z)+(\s*))(Desc:|Author:|\Z)))', re.MULTILINE)


class BlueprintDocstring(PolicyImplementationDocstring):
    """Representation of a docstring for a customer blueprint.

    Author:
        ashah@oak9.io

    Name:
        Aakash's Blueprint

    """

    @property
    def name(self) -> str:
        """
        Returns blueprint name
        """
        name = self._get_str_field(name_pattern, 'name', "Blueprint name was not provided in docstring")
        return name

    @property
    def desc(self) -> str:
        """
        Returns blueprint name
        """
        empty_msg = "No description provided in docstring"
        desc = self._get_str_field(desc_pattern, 'desc', empty_msg)
        if desc == empty_msg:
            desc = self._get_str_field(no_desc_pattern, 'nodesc', empty_msg)


        return desc

    @property
    def author(self) -> str:
        """
        Returns blueprint name
        """
        author = self._get_str_field(author_pattern, 'author', "No description provided in docstring")
        return author





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_streamanalytics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+azure/azure_microsoft_streamanalytics.proto\x12+oak9.tython.azure.microsoft_streamanalytics\x1a\x13shared/shared.proto\"\x96\x03\n\x19Microsoft_StreamAnalytics\x12Q\n\rstreamingjobs\x18\x01 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Streamingjobs\x12\x64\n\x17streamingjobs_functions\x18\x02 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_streamanalytics.StreamingjobsFunctions\x12^\n\x14streamingjobs_inputs\x18\x03 \x03(\x0b\x32@.oak9.tython.azure.microsoft_streamanalytics.StreamingjobsInputs\x12`\n\x15streamingjobs_outputs\x18\x04 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_streamanalytics.StreamingjobsOutputs\"\xac\x01\n\x1cStreamingjobsTransformations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x17\n\x0fstreaming_units\x18\x04 \x01(\x05\x12\x1d\n\x15valid_streaming_units\x18\x05 \x03(\x05\"\xad\x02\n\x14StreamingjobsOutputs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\ndatasource\x18\x03 \x01(\x0b\x32=.oak9.tython.azure.microsoft_streamanalytics.OutputDataSource\x12Q\n\rserialization\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Serialization\x12\x13\n\x0bsize_window\x18\x05 \x01(\x01\x12\x13\n\x0btime_window\x18\x06 \x01(\t\"\x95\x02\n\x13StreamingjobsInputs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12M\n\x0b\x63ompression\x18\x03 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_streamanalytics.Compression\x12\x15\n\rpartition_key\x18\x04 \x01(\t\x12Q\n\rserialization\x18\x05 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Serialization\"\xc7\x02\n\x16StreamingjobsFunctions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12M\n\x07\x62inding\x18\x03 \x01(\x0b\x32<.oak9.tython.azure.microsoft_streamanalytics.FunctionBinding\x12J\n\x06inputs\x18\x04 \x03(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.FunctionInput\x12K\n\x06output\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_streamanalytics.FunctionOutput\"\xcb\t\n\rStreamingjobs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x08identity\x18\x02 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_streamanalytics.Identity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12I\n\x07\x63luster\x18\x05 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_streamanalytics.ClusterInfo\x12\x1b\n\x13\x63ompatibility_level\x18\x06 \x01(\t\x12\x1e\n\x16\x63ontent_storage_policy\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x61ta_locale\x18\x08 \x01(\t\x12\x30\n(events_late_arrival_max_delay_in_seconds\x18\t \x01(\x05\x12\x30\n(events_out_of_order_max_delay_in_seconds\x18\n \x01(\x05\x12\"\n\x1a\x65vents_out_of_order_policy\x18\x0b \x01(\t\x12H\n\texternals\x18\x0c \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_streamanalytics.External\x12H\n\tfunctions\x18\r \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_streamanalytics.Function\x12\x42\n\x06inputs\x18\x0e \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_streamanalytics.Input\x12[\n\x13job_storage_account\x18\x0f \x01(\x0b\x32>.oak9.tython.azure.microsoft_streamanalytics.JobStorageAccount\x12\x10\n\x08job_type\x18\x10 \x01(\t\x12\x1b\n\x13output_error_policy\x18\x11 \x01(\t\x12\x44\n\x07outputs\x18\x12 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_streamanalytics.Output\x12\x19\n\x11output_start_mode\x18\x13 \x01(\t\x12\x19\n\x11output_start_time\x18\x14 \x01(\t\x12=\n\x03sku\x18\x15 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_streamanalytics.Sku\x12S\n\x0etransformation\x18\x16 \x01(\x0b\x32;.oak9.tython.azure.microsoft_streamanalytics.Transformation\x12R\n\x04tags\x18\x17 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_streamanalytics.Streamingjobs.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x0eTransformation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x17\n\x0fstreaming_units\x18\x03 \x01(\x05\x12\x1d\n\x15valid_streaming_units\x18\x04 \x03(\x05\"\x13\n\x03Sku\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe6\x01\n\x06Output\x12\x0c\n\x04name\x18\x01 \x01(\t\x12Q\n\ndatasource\x18\x02 \x01(\x0b\x32=.oak9.tython.azure.microsoft_streamanalytics.OutputDataSource\x12Q\n\rserialization\x18\x03 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Serialization\x12\x13\n\x0bsize_window\x18\x04 \x01(\x01\x12\x13\n\x0btime_window\x18\x05 \x01(\t\" \n\x10OutputDataSource\x12\x0c\n\x04name\x18\x01 \x01(\t\"[\n\x11JobStorageAccount\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x1b\n\x13\x61uthentication_mode\x18\x03 \x01(\t\"\xce\x01\n\x05Input\x12\x0c\n\x04name\x18\x01 \x01(\t\x12M\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_streamanalytics.Compression\x12\x15\n\rpartition_key\x18\x03 \x01(\t\x12Q\n\rserialization\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.Serialization\"\x1d\n\rSerialization\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1b\n\x0b\x43ompression\x12\x0c\n\x04type\x18\x01 \x01(\t\"\x80\x02\n\x08\x46unction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12M\n\x07\x62inding\x18\x02 \x01(\x0b\x32<.oak9.tython.azure.microsoft_streamanalytics.FunctionBinding\x12J\n\x06inputs\x18\x03 \x03(\x0b\x32:.oak9.tython.azure.microsoft_streamanalytics.FunctionInput\x12K\n\x06output\x18\x04 \x01(\x0b\x32;.oak9.tython.azure.microsoft_streamanalytics.FunctionOutput\"#\n\x0e\x46unctionOutput\x12\x11\n\tdata_type\x18\x01 \x01(\t\"F\n\rFunctionInput\x12\x11\n\tdata_type\x18\x01 \x01(\t\x12\"\n\x1ais_configuration_parameter\x18\x02 \x01(\x08\"0\n\x0f\x46unctionBinding\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\"\x81\x01\n\x08\x45xternal\x12\x11\n\tcontainer\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12T\n\x0fstorage_account\x18\x03 \x01(\x0b\x32;.oak9.tython.azure.microsoft_streamanalytics.StorageAccount\";\n\x0eStorageAccount\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\"\x19\n\x0b\x43lusterInfo\x12\n\n\x02id\x18\x01 \x01(\t\"\xf5\x01\n\x08Identity\x12\x14\n\x0cprincipal_id\x18\x01 \x01(\t\x12\x11\n\ttenant_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12s\n\x18user_assigned_identities\x18\x04 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_streamanalytics.Identity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_streamanalytics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STREAMINGJOBS_TAGSENTRY._options = None
  _STREAMINGJOBS_TAGSENTRY._serialized_options = b'8\001'
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_STREAMANALYTICS._serialized_start=114
  _MICROSOFT_STREAMANALYTICS._serialized_end=520
  _STREAMINGJOBSTRANSFORMATIONS._serialized_start=523
  _STREAMINGJOBSTRANSFORMATIONS._serialized_end=695
  _STREAMINGJOBSOUTPUTS._serialized_start=698
  _STREAMINGJOBSOUTPUTS._serialized_end=999
  _STREAMINGJOBSINPUTS._serialized_start=1002
  _STREAMINGJOBSINPUTS._serialized_end=1279
  _STREAMINGJOBSFUNCTIONS._serialized_start=1282
  _STREAMINGJOBSFUNCTIONS._serialized_end=1609
  _STREAMINGJOBS._serialized_start=1612
  _STREAMINGJOBS._serialized_end=2839
  _STREAMINGJOBS_TAGSENTRY._serialized_start=2796
  _STREAMINGJOBS_TAGSENTRY._serialized_end=2839
  _TRANSFORMATION._serialized_start=2841
  _TRANSFORMATION._serialized_end=2942
  _SKU._serialized_start=2944
  _SKU._serialized_end=2963
  _OUTPUT._serialized_start=2966
  _OUTPUT._serialized_end=3196
  _OUTPUTDATASOURCE._serialized_start=3198
  _OUTPUTDATASOURCE._serialized_end=3230
  _JOBSTORAGEACCOUNT._serialized_start=3232
  _JOBSTORAGEACCOUNT._serialized_end=3323
  _INPUT._serialized_start=3326
  _INPUT._serialized_end=3532
  _SERIALIZATION._serialized_start=3534
  _SERIALIZATION._serialized_end=3563
  _COMPRESSION._serialized_start=3565
  _COMPRESSION._serialized_end=3592
  _FUNCTION._serialized_start=3595
  _FUNCTION._serialized_end=3851
  _FUNCTIONOUTPUT._serialized_start=3853
  _FUNCTIONOUTPUT._serialized_end=3888
  _FUNCTIONINPUT._serialized_start=3890
  _FUNCTIONINPUT._serialized_end=3960
  _FUNCTIONBINDING._serialized_start=3962
  _FUNCTIONBINDING._serialized_end=4010
  _EXTERNAL._serialized_start=4013
  _EXTERNAL._serialized_end=4142
  _STORAGEACCOUNT._serialized_start=4144
  _STORAGEACCOUNT._serialized_end=4203
  _CLUSTERINFO._serialized_start=4205
  _CLUSTERINFO._serialized_end=4230
  _IDENTITY._serialized_start=4233
  _IDENTITY._serialized_end=4478
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=4417
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=4478
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_HealthcareApis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICES_FIELD_NUMBER: builtins.int
    @property
    def services(self) -> global___Services: ...
    def __init__(
        self,
        *,
        services: global___Services | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["services", b"services"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["services", b"services"]) -> None: ...

global___Microsoft_HealthcareApis = Microsoft_HealthcareApis

@typing_extensions.final
class WorkspacesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
        system_data: global___SystemData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "system_data", b"system_data"]) -> None: ...

global___WorkspacesPrivateEndpointConnections = WorkspacesPrivateEndpointConnections

@typing_extensions.final
class WorkspacesIotconnectorsFhirdestinations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FHIR_MAPPING_FIELD_NUMBER: builtins.int
    FHIR_SERVICE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    RESOURCE_IDENTITY_RESOLUTION_TYPE_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def fhir_mapping(self) -> global___IotMappingProperties: ...
    fhir_service_resource_id: builtins.str
    provisioning_state: builtins.str
    resource_identity_resolution_type: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        fhir_mapping: global___IotMappingProperties | None = ...,
        fhir_service_resource_id: builtins.str = ...,
        provisioning_state: builtins.str = ...,
        resource_identity_resolution_type: builtins.str = ...,
        system_data: global___SystemData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fhir_mapping", b"fhir_mapping", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "fhir_mapping", b"fhir_mapping", "fhir_service_resource_id", b"fhir_service_resource_id", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "resource_identity_resolution_type", b"resource_identity_resolution_type", "resource_info", b"resource_info", "system_data", b"system_data"]) -> None: ...

global___WorkspacesIotconnectorsFhirdestinations = WorkspacesIotconnectorsFhirdestinations

@typing_extensions.final
class WorkspacesIotconnectors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEVICE_MAPPING_FIELD_NUMBER: builtins.int
    INGESTION_ENDPOINT_CONFIGURATION_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    WORKSPACES_IOTCONNECTORS_FHIRDESTINATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ServiceManagedIdentityIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def device_mapping(self) -> global___IotMappingProperties: ...
    @property
    def ingestion_endpoint_configuration(self) -> global___IotEventHubIngestionEndpointConfiguration: ...
    provisioning_state: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def workspaces_iotconnectors_fhirdestinations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesIotconnectorsFhirdestinations]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ServiceManagedIdentityIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        device_mapping: global___IotMappingProperties | None = ...,
        ingestion_endpoint_configuration: global___IotEventHubIngestionEndpointConfiguration | None = ...,
        provisioning_state: builtins.str = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        workspaces_iotconnectors_fhirdestinations: collections.abc.Iterable[global___WorkspacesIotconnectorsFhirdestinations] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["device_mapping", b"device_mapping", "identity", b"identity", "ingestion_endpoint_configuration", b"ingestion_endpoint_configuration", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_mapping", b"device_mapping", "identity", b"identity", "ingestion_endpoint_configuration", b"ingestion_endpoint_configuration", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "system_data", b"system_data", "tags", b"tags", "workspaces_iotconnectors_fhirdestinations", b"workspaces_iotconnectors_fhirdestinations"]) -> None: ...

global___WorkspacesIotconnectors = WorkspacesIotconnectors

@typing_extensions.final
class IotEventHubIngestionEndpointConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUMER_GROUP_FIELD_NUMBER: builtins.int
    EVENT_HUB_NAME_FIELD_NUMBER: builtins.int
    FULLY_QUALIFIED_EVENT_HUB_NAMESPACE_FIELD_NUMBER: builtins.int
    consumer_group: builtins.str
    event_hub_name: builtins.str
    fully_qualified_event_hub_namespace: builtins.str
    def __init__(
        self,
        *,
        consumer_group: builtins.str = ...,
        event_hub_name: builtins.str = ...,
        fully_qualified_event_hub_namespace: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["consumer_group", b"consumer_group", "event_hub_name", b"event_hub_name", "fully_qualified_event_hub_namespace", b"fully_qualified_event_hub_namespace"]) -> None: ...

global___IotEventHubIngestionEndpointConfiguration = IotEventHubIngestionEndpointConfiguration

@typing_extensions.final
class IotMappingProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ContentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTENT_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        content: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___IotMappingProperties = IotMappingProperties

@typing_extensions.final
class WorkspacesFhirservices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACCESS_POLICIES_FIELD_NUMBER: builtins.int
    ACR_CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    CORS_CONFIGURATION_FIELD_NUMBER: builtins.int
    EVENT_STATE_FIELD_NUMBER: builtins.int
    EXPORT_CONFIGURATION_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    RESOURCE_VERSION_POLICY_CONFIGURATION_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ServiceManagedIdentityIdentity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def access_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FhirServiceAccessPolicyEntry]: ...
    @property
    def acr_configuration(self) -> global___FhirServiceAcrConfiguration: ...
    @property
    def authentication_configuration(self) -> global___FhirServiceAuthenticationConfiguration: ...
    @property
    def cors_configuration(self) -> global___FhirServiceCorsConfiguration: ...
    event_state: builtins.str
    @property
    def export_configuration(self) -> global___FhirServiceExportConfiguration: ...
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def resource_version_policy_configuration(self) -> global___ResourceVersionPolicyConfiguration: ...
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ServiceManagedIdentityIdentity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        access_policies: collections.abc.Iterable[global___FhirServiceAccessPolicyEntry] | None = ...,
        acr_configuration: global___FhirServiceAcrConfiguration | None = ...,
        authentication_configuration: global___FhirServiceAuthenticationConfiguration | None = ...,
        cors_configuration: global___FhirServiceCorsConfiguration | None = ...,
        event_state: builtins.str = ...,
        export_configuration: global___FhirServiceExportConfiguration | None = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        resource_version_policy_configuration: global___ResourceVersionPolicyConfiguration | None = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["acr_configuration", b"acr_configuration", "authentication_configuration", b"authentication_configuration", "cors_configuration", b"cors_configuration", "export_configuration", b"export_configuration", "identity", b"identity", "resource_info", b"resource_info", "resource_version_policy_configuration", b"resource_version_policy_configuration", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_policies", b"access_policies", "acr_configuration", b"acr_configuration", "authentication_configuration", b"authentication_configuration", "cors_configuration", b"cors_configuration", "event_state", b"event_state", "export_configuration", b"export_configuration", "identity", b"identity", "kind", b"kind", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "resource_version_policy_configuration", b"resource_version_policy_configuration", "system_data", b"system_data", "tags", b"tags"]) -> None: ...

global___WorkspacesFhirservices = WorkspacesFhirservices

@typing_extensions.final
class ResourceVersionPolicyConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResourceTypeOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFAULT_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_OVERRIDES_FIELD_NUMBER: builtins.int
    default: builtins.str
    @property
    def resource_type_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        default: builtins.str = ...,
        resource_type_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default", b"default", "resource_type_overrides", b"resource_type_overrides"]) -> None: ...

global___ResourceVersionPolicyConfiguration = ResourceVersionPolicyConfiguration

@typing_extensions.final
class FhirServiceExportConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    storage_account_name: builtins.str
    def __init__(
        self,
        *,
        storage_account_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["storage_account_name", b"storage_account_name"]) -> None: ...

global___FhirServiceExportConfiguration = FhirServiceExportConfiguration

@typing_extensions.final
class FhirServiceCorsConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    METHODS_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.int
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.int = ...,
        methods: collections.abc.Iterable[builtins.str] | None = ...,
        origins: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "headers", b"headers", "max_age", b"max_age", "methods", b"methods", "origins", b"origins"]) -> None: ...

global___FhirServiceCorsConfiguration = FhirServiceCorsConfiguration

@typing_extensions.final
class FhirServiceAuthenticationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    SMART_PROXY_ENABLED_FIELD_NUMBER: builtins.int
    audience: builtins.str
    authority: builtins.str
    smart_proxy_enabled: builtins.bool
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        authority: builtins.str = ...,
        smart_proxy_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "authority", b"authority", "smart_proxy_enabled", b"smart_proxy_enabled"]) -> None: ...

global___FhirServiceAuthenticationConfiguration = FhirServiceAuthenticationConfiguration

@typing_extensions.final
class FhirServiceAcrConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGIN_SERVERS_FIELD_NUMBER: builtins.int
    OCI_ARTIFACTS_FIELD_NUMBER: builtins.int
    @property
    def login_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def oci_artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceOciArtifactEntry]: ...
    def __init__(
        self,
        *,
        login_servers: collections.abc.Iterable[builtins.str] | None = ...,
        oci_artifacts: collections.abc.Iterable[global___ServiceOciArtifactEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["login_servers", b"login_servers", "oci_artifacts", b"oci_artifacts"]) -> None: ...

global___FhirServiceAcrConfiguration = FhirServiceAcrConfiguration

@typing_extensions.final
class FhirServiceAccessPolicyEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_FIELD_NUMBER: builtins.int
    object_id: builtins.str
    def __init__(
        self,
        *,
        object_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id", b"object_id"]) -> None: ...

global___FhirServiceAccessPolicyEntry = FhirServiceAccessPolicyEntry

@typing_extensions.final
class WorkspacesDicomservices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ServiceManagedIdentityIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def authentication_configuration(self) -> global___DicomServiceAuthenticationConfiguration: ...
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ServiceManagedIdentityIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        authentication_configuration: global___DicomServiceAuthenticationConfiguration | None = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "identity", b"identity", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_configuration", b"authentication_configuration", "identity", b"identity", "location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "system_data", b"system_data", "tags", b"tags"]) -> None: ...

global___WorkspacesDicomservices = WorkspacesDicomservices

@typing_extensions.final
class DicomServiceAuthenticationConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DicomServiceAuthenticationConfiguration = DicomServiceAuthenticationConfiguration

@typing_extensions.final
class ServiceManagedIdentityIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ServiceManagedIdentityIdentity = ServiceManagedIdentityIdentity

@typing_extensions.final
class Workspaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    WORKSPACES_DICOMSERVICES_FIELD_NUMBER: builtins.int
    WORKSPACES_IOTCONNECTORS_FIELD_NUMBER: builtins.int
    WORKSPACES_FHIRSERVICES_FIELD_NUMBER: builtins.int
    WORKSPACES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def workspaces_dicomservices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesDicomservices]: ...
    @property
    def workspaces_iotconnectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesIotconnectors]: ...
    @property
    def workspaces_fhirservices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesFhirservices]: ...
    @property
    def workspaces_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WorkspacesPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        workspaces_dicomservices: collections.abc.Iterable[global___WorkspacesDicomservices] | None = ...,
        workspaces_iotconnectors: collections.abc.Iterable[global___WorkspacesIotconnectors] | None = ...,
        workspaces_fhirservices: collections.abc.Iterable[global___WorkspacesFhirservices] | None = ...,
        workspaces_private_endpoint_connections: collections.abc.Iterable[global___WorkspacesPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "system_data", b"system_data", "tags", b"tags", "workspaces_dicomservices", b"workspaces_dicomservices", "workspaces_fhirservices", b"workspaces_fhirservices", "workspaces_iotconnectors", b"workspaces_iotconnectors", "workspaces_private_endpoint_connections", b"workspaces_private_endpoint_connections"]) -> None: ...

global___Workspaces = Workspaces

@typing_extensions.final
class ServicesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___ServicesPrivateEndpointConnections = ServicesPrivateEndpointConnections

@typing_extensions.final
class Services(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACCESS_POLICIES_FIELD_NUMBER: builtins.int
    ACR_CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTHENTICATION_CONFIGURATION_FIELD_NUMBER: builtins.int
    CORS_CONFIGURATION_FIELD_NUMBER: builtins.int
    COSMOS_DB_CONFIGURATION_FIELD_NUMBER: builtins.int
    EXPORT_CONFIGURATION_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    @property
    def identity(self) -> global___ServicesResourceIdentity: ...
    kind: builtins.str
    location: builtins.str
    name: builtins.str
    @property
    def access_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceAccessPolicyEntry]: ...
    @property
    def acr_configuration(self) -> global___ServiceAcrConfigurationInfo: ...
    @property
    def authentication_configuration(self) -> global___ServiceAuthenticationConfigurationInfo: ...
    @property
    def cors_configuration(self) -> global___ServiceCorsConfigurationInfo: ...
    @property
    def cosmos_db_configuration(self) -> global___ServiceCosmosDbConfigurationInfo: ...
    @property
    def export_configuration(self) -> global___ServiceExportConfigurationInfo: ...
    @property
    def private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateEndpointConnection]: ...
    provisioning_state: builtins.str
    public_network_access: builtins.str
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        identity: global___ServicesResourceIdentity | None = ...,
        kind: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        access_policies: collections.abc.Iterable[global___ServiceAccessPolicyEntry] | None = ...,
        acr_configuration: global___ServiceAcrConfigurationInfo | None = ...,
        authentication_configuration: global___ServiceAuthenticationConfigurationInfo | None = ...,
        cors_configuration: global___ServiceCorsConfigurationInfo | None = ...,
        cosmos_db_configuration: global___ServiceCosmosDbConfigurationInfo | None = ...,
        export_configuration: global___ServiceExportConfigurationInfo | None = ...,
        private_endpoint_connections: collections.abc.Iterable[global___PrivateEndpointConnection] | None = ...,
        provisioning_state: builtins.str = ...,
        public_network_access: builtins.str = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["acr_configuration", b"acr_configuration", "authentication_configuration", b"authentication_configuration", "cors_configuration", b"cors_configuration", "cosmos_db_configuration", b"cosmos_db_configuration", "export_configuration", b"export_configuration", "identity", b"identity", "resource_info", b"resource_info", "system_data", b"system_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_policies", b"access_policies", "acr_configuration", b"acr_configuration", "authentication_configuration", b"authentication_configuration", "cors_configuration", b"cors_configuration", "cosmos_db_configuration", b"cosmos_db_configuration", "etag", b"etag", "export_configuration", b"export_configuration", "identity", b"identity", "kind", b"kind", "location", b"location", "name", b"name", "private_endpoint_connections", b"private_endpoint_connections", "provisioning_state", b"provisioning_state", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "system_data", b"system_data", "tags", b"tags"]) -> None: ...

global___Services = Services

@typing_extensions.final
class SystemData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_BY_TYPE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_TYPE_FIELD_NUMBER: builtins.int
    created_at: builtins.str
    created_by: builtins.str
    created_by_type: builtins.str
    last_modified_at: builtins.str
    last_modified_by: builtins.str
    last_modified_by_type: builtins.str
    def __init__(
        self,
        *,
        created_at: builtins.str = ...,
        created_by: builtins.str = ...,
        created_by_type: builtins.str = ...,
        last_modified_at: builtins.str = ...,
        last_modified_by: builtins.str = ...,
        last_modified_by_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "created_by_type", b"created_by_type", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by", "last_modified_by_type", b"last_modified_by_type"]) -> None: ...

global___SystemData = SystemData

@typing_extensions.final
class PrivateEndpointConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state"]) -> None: ...

global___PrivateEndpointConnection = PrivateEndpointConnection

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class ServiceExportConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    storage_account_name: builtins.str
    def __init__(
        self,
        *,
        storage_account_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["storage_account_name", b"storage_account_name"]) -> None: ...

global___ServiceExportConfigurationInfo = ServiceExportConfigurationInfo

@typing_extensions.final
class ServiceCosmosDbConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_KEY_URI_FIELD_NUMBER: builtins.int
    OFFER_THROUGHPUT_FIELD_NUMBER: builtins.int
    key_vault_key_uri: builtins.str
    offer_throughput: builtins.int
    def __init__(
        self,
        *,
        key_vault_key_uri: builtins.str = ...,
        offer_throughput: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_key_uri", b"key_vault_key_uri", "offer_throughput", b"offer_throughput"]) -> None: ...

global___ServiceCosmosDbConfigurationInfo = ServiceCosmosDbConfigurationInfo

@typing_extensions.final
class ServiceCorsConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    METHODS_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.int
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.int = ...,
        methods: collections.abc.Iterable[builtins.str] | None = ...,
        origins: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "headers", b"headers", "max_age", b"max_age", "methods", b"methods", "origins", b"origins"]) -> None: ...

global___ServiceCorsConfigurationInfo = ServiceCorsConfigurationInfo

@typing_extensions.final
class ServiceAuthenticationConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    SMART_PROXY_ENABLED_FIELD_NUMBER: builtins.int
    audience: builtins.str
    authority: builtins.str
    smart_proxy_enabled: builtins.bool
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        authority: builtins.str = ...,
        smart_proxy_enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "authority", b"authority", "smart_proxy_enabled", b"smart_proxy_enabled"]) -> None: ...

global___ServiceAuthenticationConfigurationInfo = ServiceAuthenticationConfigurationInfo

@typing_extensions.final
class ServiceAcrConfigurationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGIN_SERVERS_FIELD_NUMBER: builtins.int
    OCI_ARTIFACTS_FIELD_NUMBER: builtins.int
    @property
    def login_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def oci_artifacts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceOciArtifactEntry]: ...
    def __init__(
        self,
        *,
        login_servers: collections.abc.Iterable[builtins.str] | None = ...,
        oci_artifacts: collections.abc.Iterable[global___ServiceOciArtifactEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["login_servers", b"login_servers", "oci_artifacts", b"oci_artifacts"]) -> None: ...

global___ServiceAcrConfigurationInfo = ServiceAcrConfigurationInfo

@typing_extensions.final
class ServiceOciArtifactEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIGEST_FIELD_NUMBER: builtins.int
    IMAGE_NAME_FIELD_NUMBER: builtins.int
    LOGIN_SERVER_FIELD_NUMBER: builtins.int
    digest: builtins.str
    image_name: builtins.str
    login_server: builtins.str
    def __init__(
        self,
        *,
        digest: builtins.str = ...,
        image_name: builtins.str = ...,
        login_server: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest", b"digest", "image_name", b"image_name", "login_server", b"login_server"]) -> None: ...

global___ServiceOciArtifactEntry = ServiceOciArtifactEntry

@typing_extensions.final
class ServiceAccessPolicyEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_FIELD_NUMBER: builtins.int
    object_id: builtins.str
    def __init__(
        self,
        *,
        object_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id", b"object_id"]) -> None: ...

global___ServiceAccessPolicyEntry = ServiceAccessPolicyEntry

@typing_extensions.final
class ServicesResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ServicesResourceIdentity = ServicesResourceIdentity



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CustomResourceColumnDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    JSON_PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    format: builtins.str
    json_path: builtins.str
    name: builtins.str
    priority: builtins.int
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        format: builtins.str = ...,
        json_path: builtins.str = ...,
        name: builtins.str = ...,
        priority: builtins.int = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "format", b"format", "json_path", b"json_path", "name", b"name", "priority", b"priority", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___CustomResourceColumnDefinition = CustomResourceColumnDefinition

@typing_extensions.final
class CustomResourceConversion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRATEGY_FIELD_NUMBER: builtins.int
    WEBHOOK_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    strategy: builtins.str
    @property
    def webhook(self) -> global___WebhookConversion: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        strategy: builtins.str = ...,
        webhook: global___WebhookConversion | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "webhook", b"webhook"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "strategy", b"strategy", "webhook", b"webhook"]) -> None: ...

global___CustomResourceConversion = CustomResourceConversion

@typing_extensions.final
class CustomResourceDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___CustomResourceDefinitionSpec: ...
    @property
    def status(self) -> global___CustomResourceDefinitionStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___CustomResourceDefinitionSpec | None = ...,
        status: global___CustomResourceDefinitionStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___CustomResourceDefinition = CustomResourceDefinition

@typing_extensions.final
class CustomResourceDefinitionCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___CustomResourceDefinitionCondition = CustomResourceDefinitionCondition

@typing_extensions.final
class CustomResourceDefinitionList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomResourceDefinition]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___CustomResourceDefinition] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___CustomResourceDefinitionList = CustomResourceDefinitionList

@typing_extensions.final
class CustomResourceDefinitionNames(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATEGORIES_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    LIST_KIND_FIELD_NUMBER: builtins.int
    PLURAL_FIELD_NUMBER: builtins.int
    SHORT_NAMES_FIELD_NUMBER: builtins.int
    SINGULAR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def categories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    kind: builtins.str
    list_kind: builtins.str
    plural: builtins.str
    @property
    def short_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    singular: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        categories: collections.abc.Iterable[builtins.str] | None = ...,
        kind: builtins.str = ...,
        list_kind: builtins.str = ...,
        plural: builtins.str = ...,
        short_names: collections.abc.Iterable[builtins.str] | None = ...,
        singular: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["categories", b"categories", "kind", b"kind", "list_kind", b"list_kind", "plural", b"plural", "resource_info", b"resource_info", "short_names", b"short_names", "singular", b"singular"]) -> None: ...

global___CustomResourceDefinitionNames = CustomResourceDefinitionNames

@typing_extensions.final
class CustomResourceDefinitionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSION_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    NAMES_FIELD_NUMBER: builtins.int
    PRESERVE_UNKNOWN_FIELDS_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conversion(self) -> global___CustomResourceConversion: ...
    group: builtins.str
    @property
    def names(self) -> global___CustomResourceDefinitionNames: ...
    preserve_unknown_fields: builtins.bool
    scope: builtins.str
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomResourceDefinitionVersion]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conversion: global___CustomResourceConversion | None = ...,
        group: builtins.str = ...,
        names: global___CustomResourceDefinitionNames | None = ...,
        preserve_unknown_fields: builtins.bool = ...,
        scope: builtins.str = ...,
        versions: collections.abc.Iterable[global___CustomResourceDefinitionVersion] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conversion", b"conversion", "names", b"names", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conversion", b"conversion", "group", b"group", "names", b"names", "preserve_unknown_fields", b"preserve_unknown_fields", "resource_info", b"resource_info", "scope", b"scope", "versions", b"versions"]) -> None: ...

global___CustomResourceDefinitionSpec = CustomResourceDefinitionSpec

@typing_extensions.final
class CustomResourceDefinitionStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPTED_NAMES_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    STORED_VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def accepted_names(self) -> global___CustomResourceDefinitionNames: ...
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomResourceDefinitionCondition]: ...
    @property
    def stored_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        accepted_names: global___CustomResourceDefinitionNames | None = ...,
        conditions: collections.abc.Iterable[global___CustomResourceDefinitionCondition] | None = ...,
        stored_versions: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accepted_names", b"accepted_names", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_names", b"accepted_names", "conditions", b"conditions", "resource_info", b"resource_info", "stored_versions", b"stored_versions"]) -> None: ...

global___CustomResourceDefinitionStatus = CustomResourceDefinitionStatus

@typing_extensions.final
class CustomResourceDefinitionVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONAL_PRINTER_COLUMNS_FIELD_NUMBER: builtins.int
    DEPRECATED_FIELD_NUMBER: builtins.int
    DEPRECATION_WARNING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SERVED_FIELD_NUMBER: builtins.int
    STORAGE_FIELD_NUMBER: builtins.int
    SUBRESOURCES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def additional_printer_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomResourceColumnDefinition]: ...
    deprecated: builtins.bool
    deprecation_warning: builtins.str
    name: builtins.str
    @property
    def schema(self) -> global___CustomResourceValidation: ...
    served: builtins.bool
    storage: builtins.bool
    @property
    def subresources(self) -> global___CustomResourceSubresources: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        additional_printer_columns: collections.abc.Iterable[global___CustomResourceColumnDefinition] | None = ...,
        deprecated: builtins.bool = ...,
        deprecation_warning: builtins.str = ...,
        name: builtins.str = ...,
        schema: global___CustomResourceValidation | None = ...,
        served: builtins.bool = ...,
        storage: builtins.bool = ...,
        subresources: global___CustomResourceSubresources | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schema", b"schema", "subresources", b"subresources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_printer_columns", b"additional_printer_columns", "deprecated", b"deprecated", "deprecation_warning", b"deprecation_warning", "name", b"name", "resource_info", b"resource_info", "schema", b"schema", "served", b"served", "storage", b"storage", "subresources", b"subresources"]) -> None: ...

global___CustomResourceDefinitionVersion = CustomResourceDefinitionVersion

@typing_extensions.final
class CustomResourceSubresourceScale(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_SELECTOR_PATH_FIELD_NUMBER: builtins.int
    SPEC_REPLICAS_PATH_FIELD_NUMBER: builtins.int
    STATUS_REPLICAS_PATH_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    label_selector_path: builtins.str
    spec_replicas_path: builtins.str
    status_replicas_path: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        label_selector_path: builtins.str = ...,
        spec_replicas_path: builtins.str = ...,
        status_replicas_path: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["label_selector_path", b"label_selector_path", "resource_info", b"resource_info", "spec_replicas_path", b"spec_replicas_path", "status_replicas_path", b"status_replicas_path"]) -> None: ...

global___CustomResourceSubresourceScale = CustomResourceSubresourceScale

@typing_extensions.final
class CustomResourceSubresourceStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___CustomResourceSubresourceStatus = CustomResourceSubresourceStatus

@typing_extensions.final
class CustomResourceSubresources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCALE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def scale(self) -> global___CustomResourceSubresourceScale: ...
    @property
    def status(self) -> global___CustomResourceSubresourceStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        scale: global___CustomResourceSubresourceScale | None = ...,
        status: global___CustomResourceSubresourceStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scale", b"scale", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scale", b"scale", "status", b"status"]) -> None: ...

global___CustomResourceSubresources = CustomResourceSubresources

@typing_extensions.final
class CustomResourceValidation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPEN_A_P_I_V3_SCHEMA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def open_a_p_i_v3_schema(self) -> global___JSONSchemaProps: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        open_a_p_i_v3_schema: global___JSONSchemaProps | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["open_a_p_i_v3_schema", b"open_a_p_i_v3_schema", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["open_a_p_i_v3_schema", b"open_a_p_i_v3_schema", "resource_info", b"resource_info"]) -> None: ...

global___CustomResourceValidation = CustomResourceValidation

@typing_extensions.final
class ExternalDocumentation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    url: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        url: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info", "url", b"url"]) -> None: ...

global___ExternalDocumentation = ExternalDocumentation

@typing_extensions.final
class JSON(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___JSON = JSON

@typing_extensions.final
class JSONSchemaProps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DefinitionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class DependenciesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class PatternPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADDITIONAL_ITEMS_FIELD_NUMBER: builtins.int
    ADDITIONAL_PROPERTIES_FIELD_NUMBER: builtins.int
    ALL_OF_FIELD_NUMBER: builtins.int
    ANY_OF_FIELD_NUMBER: builtins.int
    DEFAULT_FIELD_NUMBER: builtins.int
    DEFINITIONS_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENUM_FIELD_NUMBER: builtins.int
    EXAMPLE_FIELD_NUMBER: builtins.int
    EXCLUSIVE_MAXIMUM_FIELD_NUMBER: builtins.int
    EXCLUSIVE_MINIMUM_FIELD_NUMBER: builtins.int
    EXTERNAL_DOCS_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    MAX_ITEMS_FIELD_NUMBER: builtins.int
    MAX_LENGTH_FIELD_NUMBER: builtins.int
    MAX_PROPERTIES_FIELD_NUMBER: builtins.int
    MAXIMUM_FIELD_NUMBER: builtins.int
    MIN_ITEMS_FIELD_NUMBER: builtins.int
    MIN_LENGTH_FIELD_NUMBER: builtins.int
    MIN_PROPERTIES_FIELD_NUMBER: builtins.int
    MINIMUM_FIELD_NUMBER: builtins.int
    MULTIPLE_OF_FIELD_NUMBER: builtins.int
    NOT_FIELD_NUMBER: builtins.int
    NULLABLE_FIELD_NUMBER: builtins.int
    ONE_OF_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    PATTERN_PROPERTIES_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UNIQUE_ITEMS_FIELD_NUMBER: builtins.int
    XKUBERNETESEMBEDDEDRESOURCE_FIELD_NUMBER: builtins.int
    XKUBERNETESINTORSTRING_FIELD_NUMBER: builtins.int
    XKUBERNETESLISTMAPKEYS_FIELD_NUMBER: builtins.int
    XKUBERNETESLISTTYPE_FIELD_NUMBER: builtins.int
    XKUBERNETESMAPTYPE_FIELD_NUMBER: builtins.int
    XKUBERNETESPRESERVEUNKNOWNFIELDS_FIELD_NUMBER: builtins.int
    XKUBERNETESVALIDATIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def additional_items(self) -> global___JSONSchemaPropsOrBool: ...
    @property
    def additional_properties(self) -> global___JSONSchemaPropsOrBool: ...
    @property
    def all_of(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JSONSchemaProps]: ...
    @property
    def any_of(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JSONSchemaProps]: ...
    @property
    def default(self) -> global___JSON: ...
    @property
    def definitions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def dependencies(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    description: builtins.str
    @property
    def enum(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JSON]: ...
    @property
    def example(self) -> global___JSON: ...
    exclusive_maximum: builtins.bool
    exclusive_minimum: builtins.bool
    @property
    def external_docs(self) -> global___ExternalDocumentation: ...
    format: builtins.str
    id: builtins.str
    @property
    def items(self) -> global___JSONSchemaPropsOrArray: ...
    max_items: builtins.int
    max_length: builtins.int
    max_properties: builtins.int
    maximum: builtins.float
    min_items: builtins.int
    min_length: builtins.int
    min_properties: builtins.int
    minimum: builtins.float
    multiple_of: builtins.float
    nullable: builtins.bool
    @property
    def one_of(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JSONSchemaProps]: ...
    pattern: builtins.str
    @property
    def pattern_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def required(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    title: builtins.str
    type: builtins.str
    unique_items: builtins.bool
    xkubernetesembeddedresource: builtins.bool
    xkubernetesintorstring: builtins.bool
    @property
    def xkuberneteslistmapkeys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    xkuberneteslisttype: builtins.str
    xkubernetesmaptype: builtins.str
    xkubernetespreserveunknownfields: builtins.bool
    @property
    def xkubernetesvalidations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidationRule]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        additional_items: global___JSONSchemaPropsOrBool | None = ...,
        additional_properties: global___JSONSchemaPropsOrBool | None = ...,
        all_of: collections.abc.Iterable[global___JSONSchemaProps] | None = ...,
        any_of: collections.abc.Iterable[global___JSONSchemaProps] | None = ...,
        default: global___JSON | None = ...,
        definitions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        dependencies: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        enum: collections.abc.Iterable[global___JSON] | None = ...,
        example: global___JSON | None = ...,
        exclusive_maximum: builtins.bool = ...,
        exclusive_minimum: builtins.bool = ...,
        external_docs: global___ExternalDocumentation | None = ...,
        format: builtins.str = ...,
        id: builtins.str = ...,
        items: global___JSONSchemaPropsOrArray | None = ...,
        max_items: builtins.int = ...,
        max_length: builtins.int = ...,
        max_properties: builtins.int = ...,
        maximum: builtins.float = ...,
        min_items: builtins.int = ...,
        min_length: builtins.int = ...,
        min_properties: builtins.int = ...,
        minimum: builtins.float = ...,
        multiple_of: builtins.float = ...,
        nullable: builtins.bool = ...,
        one_of: collections.abc.Iterable[global___JSONSchemaProps] | None = ...,
        pattern: builtins.str = ...,
        pattern_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        required: collections.abc.Iterable[builtins.str] | None = ...,
        title: builtins.str = ...,
        type: builtins.str = ...,
        unique_items: builtins.bool = ...,
        xkubernetesembeddedresource: builtins.bool = ...,
        xkubernetesintorstring: builtins.bool = ...,
        xkuberneteslistmapkeys: collections.abc.Iterable[builtins.str] | None = ...,
        xkuberneteslisttype: builtins.str = ...,
        xkubernetesmaptype: builtins.str = ...,
        xkubernetespreserveunknownfields: builtins.bool = ...,
        xkubernetesvalidations: collections.abc.Iterable[global___ValidationRule] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["additional_items", b"additional_items", "additional_properties", b"additional_properties", "default", b"default", "example", b"example", "external_docs", b"external_docs", "items", b"items", "not", b"not", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_items", b"additional_items", "additional_properties", b"additional_properties", "all_of", b"all_of", "any_of", b"any_of", "default", b"default", "definitions", b"definitions", "dependencies", b"dependencies", "description", b"description", "enum", b"enum", "example", b"example", "exclusive_maximum", b"exclusive_maximum", "exclusive_minimum", b"exclusive_minimum", "external_docs", b"external_docs", "format", b"format", "id", b"id", "items", b"items", "max_items", b"max_items", "max_length", b"max_length", "max_properties", b"max_properties", "maximum", b"maximum", "min_items", b"min_items", "min_length", b"min_length", "min_properties", b"min_properties", "minimum", b"minimum", "multiple_of", b"multiple_of", "not", b"not", "nullable", b"nullable", "one_of", b"one_of", "pattern", b"pattern", "pattern_properties", b"pattern_properties", "properties", b"properties", "required", b"required", "resource_info", b"resource_info", "title", b"title", "type", b"type", "unique_items", b"unique_items", "xkubernetesembeddedresource", b"xkubernetesembeddedresource", "xkubernetesintorstring", b"xkubernetesintorstring", "xkuberneteslistmapkeys", b"xkuberneteslistmapkeys", "xkuberneteslisttype", b"xkuberneteslisttype", "xkubernetesmaptype", b"xkubernetesmaptype", "xkubernetespreserveunknownfields", b"xkubernetespreserveunknownfields", "xkubernetesvalidations", b"xkubernetesvalidations"]) -> None: ...

global___JSONSchemaProps = JSONSchemaProps

@typing_extensions.final
class JSONSchemaPropsOrArray(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___JSONSchemaPropsOrArray = JSONSchemaPropsOrArray

@typing_extensions.final
class JSONSchemaPropsOrBool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___JSONSchemaPropsOrBool = JSONSchemaPropsOrBool

@typing_extensions.final
class JSONSchemaPropsOrStringArray(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___JSONSchemaPropsOrStringArray = JSONSchemaPropsOrStringArray

@typing_extensions.final
class ServiceReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    namespace: builtins.str
    path: builtins.str
    port: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        path: builtins.str = ...,
        port: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "namespace", b"namespace", "path", b"path", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___ServiceReference = ServiceReference

@typing_extensions.final
class ValidationRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    message: builtins.str
    rule: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        rule: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "resource_info", b"resource_info", "rule", b"rule"]) -> None: ...

global___ValidationRule = ValidationRule

@typing_extensions.final
class WebhookClientConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_BUNDLE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ca_bundle: builtins.str
    @property
    def service(self) -> global___ServiceReference: ...
    url: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ca_bundle: builtins.str = ...,
        service: global___ServiceReference | None = ...,
        url: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_bundle", b"ca_bundle", "resource_info", b"resource_info", "service", b"service", "url", b"url"]) -> None: ...

global___WebhookClientConfig = WebhookClientConfig

@typing_extensions.final
class WebhookConversion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_CONFIG_FIELD_NUMBER: builtins.int
    CONVERSION_REVIEW_VERSIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def client_config(self) -> global___WebhookClientConfig: ...
    @property
    def conversion_review_versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_config: global___WebhookClientConfig | None = ...,
        conversion_review_versions: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_config", b"client_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_config", b"client_config", "conversion_review_versions", b"conversion_review_versions", "resource_info", b"resource_info"]) -> None: ...

global___WebhookConversion = WebhookConversion
